#
# spec file for package praat
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           praat
Version:        6.0.49
Release:        1.1
Summary:        Phonetics by computer
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Other
URL:            http://www.praat.org
Source0:        https://github.com/praat/praat/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source3:        %{name}.changes
# PATCH-FIX-OPENSUSE praat-use_system_libs.patch -- replace some embedded libs with system ones
Patch1:         praat-use_system_libs.patch
# PATCH-FIX-OPENSUSE praat-no-return-in-nonvoid.patch -- address rpmlint complaint
Patch2:         praat-no-return-in-nonvoid.patch
BuildRequires:  ImageMagick
%if 0%{?suse_version} >= 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc7
BuildRequires:  gcc7-c++
%endif
BuildRequires:  glpk-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(portaudio-2.0)

%description
Praat is an open-software tool for the analysis of speech in phonetics.
Through its graphical interface, several speech analysis functionalities
are available: spectrograms, cochleograms, and pitch and formant extraction.
Articulatory synthesis, as well as synthesis from pitch, formant, and
intensity are also available. Other features are segmentation, labelling
using the phonetic alphabet, and computation of statistics.
Praat is configurable and extensible through its own scripting language and has
provisions for communicating with other programs.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
test -x "$(type -p gcc-7)" && export CC=gcc-7
test -x "$(type -p g++-7)" && export CXX=g++-7 LINK=g++-7
cp makefiles/makefile.defs.linux.pulse ./makefile.defs
sed -e '/^CFLAGS/s/$/\ %{optflags}/' \
    -e '/^CC/s/=/?=/' -e '/^CXX/s/=/?=/' \
    -e '/^LINK/s/=/?=/' -i makefile.defs
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}/%{_bindir} \
         %{buildroot}/%{_datadir}/pixmaps \
         %{buildroot}/%{_datadir}/applications
install -m 0755 %{name} %{buildroot}/%{_bindir}
convert -strip -resize 128x128 main/praat_win.ico %{name}.png
install -m 0644 %{name}.png %{buildroot}/%{_datadir}/pixmaps
# create .desktop file
tee %{buildroot}/%{_datadir}/applications/%{name}.desktop << "EOF"
[Desktop Entry]
Version=1.0
Type=Application
Name=Praat
GenericName=Computer phonetics
Comment=Doing phonetics by computer
Exec=praat %U
TryExec=praat
Icon=praat
Terminal=false
Categories=Science;NumericalAnalysis;GTK;
StartupNotify=true
MimeType=text/praat-textgrid;text/praat-pitch;
EOF

%files
%license main/GNU_General_Public_License.txt
%doc README.md
%{_bindir}/%{name}
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/applications/%{name}.desktop

%changelog
* Sat Mar  2 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.0.49
  * Removed a bug introduced in 6.0.41 whereby a script could
    misreport an undefined table value.
  * Removed a bug introduced in 6.0.44 whereby an MFCC's maximum
    frequency could be ignored.
  * Pitch: Tabulate candidates.
  * SoundSet.
* Sun Feb 17 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.0.48
  * Removed a bug introduced in 6.0.44 whereby Praat could crash
    when drawing a function without any points.
* Sat Feb  9 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.0.47
  * Removed a bug introduced in 6.0.44 whereby a cepstral peak
    prominence would be computed incorrectly.
* Thu Jan  3 2019 aloisio@gmx.com
- Update to version 6.0.46
  * Removed a crashing bug in the LongSound window introduced in
    6.0.44.
  * Removed a bug causing incorrect conversion from Formant to
    LPC introduced in 6.0.44.
  * More space for actions in buttons window.
* Tue Jan  1 2019 aloisio@gmx.com
- Update to version 6.0.45
  * Removed a crashing bug in EditDistanceTable introduced in
    6.0.44.
  * Removed a crashing bug in KlattGrid drawing introduced in
    6.0.44.
  * Removed a bug introduced in 6.0.44 whereby old HMM files
    were read incorrectly.
  version 6.0.44
  * Bug fixes and speed.
- Refreshed praat-no-return-in-nonvoid.patch
* Sat Sep  8 2018 aloisio@gmx.com
- Update to version 6.0.43
  * Removed a very old bug that could create invalid TextGrids
    during forced alignment.
- Refreshed praat-no-return-in-nonvoid.patch
* Thu Aug 16 2018 aloisio@gmx.com
- Update to version 6.0.42
  * Repaired a bug introduced in 6.0.41 that caused a crash in
    pause windows.
- Refreshed praat-use_system_libs.patch and
  praat-no-return-in-nonvoid.patch
* Tue Aug  7 2018 aloisio@gmx.com
- Update to version 6.0.41
  * Interoperability: the Windows edition can now communicate
    with other software in UTF-8.
- Refreshed praat-no-return-in-nonvoid.patch
* Sat May 12 2018 aloisio@gmx.com
- Update to version 6.0.40
  * Scripting: selected# ().
  * Table window: cell selection.
  * Unicode-savvy regular expressions.
- Add praat-no-return-in-nonvoid.patch
* Fri Mar 30 2018 aloisio@gmx.com
- Update to version 6.0.38
  * Concordance: ##TextGrid: Tabulate occurrences...#.
  * Some Independent Component Analysis on EEG.
  * Removed many small bugs
* Sun Feb  4 2018 aloisio@gmx.com
- Update to version 6.0.37
  * Graphics: fixed crashing bug with \un trigraph.
* Sat Nov 11 2017 aloisio@gmx.com
- Update to version 6.0.36
  * Many more languages for SpeechSynthesizer and automatic
    alignment (new eSpeak).
- Refreshed praat-use_system_libs.patch
* Tue Oct 17 2017 aloisio@gmx.com
- Update to version 6.0.35
  * Fixed a bug introduced in 6.0.23 by which Remove right
    boundary would sometimes incorrectly refuse.
* Tue Oct 10 2017 aloisio@gmx.com
- Update to version 6.0.34
  * Scripting: arrays in menu commands in scripts.
  * Inspect: made a button visible that had disappeared in 6.0.33.
* Tue Sep 26 2017 aloisio@gmx.com
- Update to version 6.0.33
  * Pitch: Subtract linear fit...: correct a bug that prevented
    computation in the ERB domain.
  * Scripting: made object[xx].xmin work again.
  * Removed a bug in Polynomial: Evaluate... introduced in 6.0.32.
- Dropped praat-fix_return_nonvoid.patch (merged upstream)
* Sun Sep 17 2017 aloisio@gmx.com
- Update to version 6.0.32
  * Table: allow spaces in column names.
  * Settings windows no longer replace your visible expressions
    with their resulting values.
  * Scripting: formulas using the tilde.
  * Optimality Theory learning: corrected a bug introduced in
    6.0.30 that could cause the editor to crash on the Mac.
  * EEG: corrected a bug that could cause an infinite loop when
    doing principal component analysis.
  * Scripting: faster interpreter.
- Refreshed praat-use_system_libs.patch
- Added praat-fix_return_nonvoid.patch
* Tue Aug 22 2017 aloisio@gmx.com
- Update to 6.0.31
  * Scripting: more vectors and matrices.
  * Numerics: faster and more precise sums, means, standard
    deviations.
- Refreshed praat-use_system_libs.patch
- Dropped praat-6.0.30-no-return-in-nonvoid.patch
* Sat Jul 29 2017 aloisio@gmx.com
- Added praat-use_system_libs.patch to use system libs when
  possible
* Sun Jul 23 2017 aloisio@gmx.com
- Update to version 6.0.30
  * Removed a bug that caused an incorrect title for a PitchTier
    or PointProcess window.
  * Removed a bug that caused Praat to crash when doing a linear
    regression on a Table with no rows.
  * Scripting: object[], vectors.
  * Graphics: better text drawing details.
  * Linux: possibility to compile Praat without a GUI but with
    graphics file output.
- Added praat-6.0.30-no-return-in-nonvoid.patch
* Sat Jun 24 2017 bwiedemann@suse.com
- Use convert -strip to not add timestamps to png files
* Wed May 24 2017 aloisio@gmx.com
- Update to 6.0.29
  * Sound window: channel muting.
  * Linux: support for Chinese, Japanese, Korean, Indic, Arabic
    and Hebrew characters in TextGrids and elsewhere.
- Dropped praat-rpmlint_warnings.patch (merged upstream)
* Mon May  8 2017 aloisio@gmx.com
- Improved description
* Thu May  4 2017 aloisio@gmx.com
- Added %%optflags
- Added praat-rpmlint_warnings.patch
* Tue May  2 2017 aloisio@gmx.com
- Corrected license
* Thu Mar 23 2017 aloisio@gmx.com
- Update to version 6.0.28
  * Scripting: demoPeekInput() for animations in combination
    with demoShow() and sleep().
* Sat Mar 18 2017 aloisio@gmx.com
- Update to version 6.0.27
  * Fixed a bug by which Remove right boundary would choose
    the wrong tier.
  * TextGrid window: click to insert a phonetic symbol from
    an IPA chart.
* Thu Mar  2 2017 aloisio@gmx.com
- Update to version 6.0.26
  * PraatBarren: better error message when an attempt is made
    to run PraatBarren interactively.
* Sun Feb 12 2017 aloisio@gmx.com
- Update to version 6.0.25
* Mon Dec 12 2016 aloisio@gmx.com
- Update to version 6.0.23
  * Linux: fixed a bug that caused Praat to crash when
    playing a sound of more than 7 channels.
  * Change Gender: fixed a bug introduced in 6.0.22 by
    which the pitch range factor could not be 0.
  * Improvements in the manual and in texts.
* Wed Nov 16 2016 aloisio@gmx.com
- Update to version 6.0.22
  * Scripting: correct error messages for expressions
    like 5 + "hello"
  * Command line: the --open option works correctly in
    the GUI if you open multiple files.
* Mon Sep 26 2016 aloisio@gmx.com
- Update to version 6.0.21
  * ExperimentMFC: you can now specify font sizes and response
    keys for goodness judgments.
  * Table: when drawing ellipses, a font size of 0 can now be
    used to prevent drawing the labels.
  * Mac: dragging selections repaired for System 10.11.6 (but
    we advise to upgrade to 10.12).
  * Mac: re-enabled Return key for confirming some dialog
    boxes.
* Sun Sep  4 2016 aloisio@gmx.com
- Update to version 6.0.20
  * Can open UTF-8 text files with Byte Order Mark.
  * Scripting improvement: function names can now be used
    as names of indexed variables.
* Tue Jul 19 2016 toddrme2178@gmail.com
- Update to version 6.0.19
  * Mac: dragging selections repaired for System 10.11.5.
* Tue May 24 2016 aloisio@gmx.com
- Update to version 6.0.18
  * Windows: better dotted lines.
  * TextGrid window: again better automatic alignment.
* Thu Apr 21 2016 aloisio@gmx.com
- Update to version 6.0.17
  * TextGrid window: better automatic alignment.
- Removed praat.png and praat.desktop as Source1 and Source2
  and produced them internally
* Tue Apr 19 2016 aloisio@gmx.com
- Initial version 6.0.16
